all:	$(DIR).a

$(DIR).a:	$(OBJ)
	ar rcs $@ $^

%.o:	%.c
	@echo CC $<; $(CC) -c $(CFLAGS) $(CPPFLAGS) $(HASGRANTPT) $< -o $@

showcc:
	@echo CC = $(CC) -c $(CFLAGS) $(CPPFLAGS) $(HASGRANTPT) FILE.c -o FILE.o | fold -w72 -s
	@echo

ifdef IS_LIB

CFLAGS  += -fPIC # for amd64

all:	lib$(NAME).so ../_include/$(NAME).h

lib$(NAME).so: $(DIR).a($(OBJ)) $(TESTDIR)
	ld  -o $@.$(VERSION) $(LDFLAGS) -shared -whole-archive $(DIR).a
	ln -sf $@.$(VERSION) $@
	cp -p lib*so* ../_lib

showlib:
	@echo LD lib = ld  -o lib$(NAME).so.$(VERSION) $(LDFLAGS) -shared -whole-archive libaspoutil.a

../_include/$(NAME).h:	$(HDR) $(TESTDIR)
	cat $(HDR) > ../_include/$(NAME).h

install: lib$(NAME).so ../_include/$(NAME).h $(TESTDIR)
	install ../_include/$(NAME)*.h $(PREFIX)/include/
	install lib$(NAME).so.$(VERSION) $(PREFIX)/lib
	ln -sf  lib$(NAME).so.$(VERSION) $(PREFIX)/lib/lib$(NAME).so
	@echo '** Do not forget to run ldconfig!'
#	ldconfig

$(PRG):	%:  %.o lib$(NAME).so
	@echo "LD $@"; $(CC) $(LDFLAGS) $@.o -l$(NAME) $(LOADLIBES) $(LDLIBS) -o $@

show:	showcc showlib
	@echo LD tst = $(CC) $(LDFLAGS) FILEs.o -l$(NAME) $(LOADLIBES) $(LDLIBS) -o FILE
	@echo

else
# not lib

all: $(NAME)

$(PRG): %: %.o $(NAME).a $(TESTDIR)
	@echo "LD $@"; $(CC) $(LDFLAGS) $@.o ./$(NAME).a $(LOADLIBES) $(LDLIBS) -o $@
	if [ $@ = $(NAME) ]; then cp -p $@ ../_bin; fi

show:	showcc
	@echo LD = $(CC) $(LDFLAGS) FILEs.o $(LOADLIBES) $(LDLIBS) -o FILE
	@echo

install: $(NAME) $(TESTDIR)
	install    $(NAME)     $(PREFIX)/bin/$(NAME)

endif
# both lib and program dirs

prg:	$(PRG)

clean:	
	-rm -f *.o *.so *~ *.core $(NAME) *.so.$(VERSION) $(PRG) $(DIR).a depend.mk $^

dep depend depend.mk: $(MSRC) $(SRC) $(HDR)
	@echo "CC -MM -MG $(SRC) > depend.mk"; $(CC) $(CFLAGS) -MM -MG $(MSRC) $(SRC) > depend.mk

$(TESTDIR):
	mkdir $@

showvar:
	@echo DIR = $(DIR)
	@echo NAME = $(NAME)
	@echo IS_LIB = $(IS_LIB)
	@echo HASGRANTPT = $(HASGRANTPT)
	@echo
	@echo MSRC = $(MSRC)
	@echo
	@echo PRG = $(PRG)
	@echo
	@echo SRC = $(SRC)
	@echo
	@echo HDR = $(HDR)
	@echo
	@echo OBJ = $(OBJ)
	@echo
	@echo CFLAGS = $(CFLAGS)
	@echo
	@echo LDFLAGS = $(LDFLAGS)

-include depend.mk

FORCE:	;
